<?php

namespace Drupal\minikanban_agent;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\user\UserInterface;

/**
 * Helper for worker agents.
 */
readonly class AgentHelper {

  public function __construct(
    private ConfigFactoryInterface $configFactory,
    private EntityTypeManagerInterface $entityTypeManager,
  ) {
  }

  /**
   * Get the AI agent user ID.
   *
   * @return int
   *   The AI Agent user ID.
   */
  public function getAiAgentId(): int {
    return (int) $this->configFactory
      ->get('minikanban_agent.settings')
      ->get('main_user');
  }

  /**
   * Get the AI agent user entity.
   *
   * @return \Drupal\user\UserInterface
   *   The AI Agent user entity.
   */
  public function getAiAgent(): UserInterface {
    return $this->entityTypeManager
      ->getStorage('user')
      ->load($this->getAiAgentId());
  }

}
