<?php

declare(strict_types=1);

namespace Drupal\minikanban_agent;

use Drupal\Core\Cache\CacheBackendInterface;
use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\Core\Plugin\DefaultPluginManager;
use Drupal\minikanban_agent\Attribute\AsyncJob;

/**
 * Plugin manager for asynchronous minikanan jobs.
 */
final class AsyncJobPluginManager extends DefaultPluginManager {

  /**
   * Constructs the object.
   */
  public function __construct(\Traversable $namespaces, CacheBackendInterface $cache_backend, ModuleHandlerInterface $module_handler) {
    parent::__construct('Plugin/MinikanbanAsyncJob', $namespaces, $module_handler, AsyncJobInterface::class, AsyncJob::class);
    $this->alterInfo('minikanban_async_job_info');
    $this->setCacheBackend($cache_backend, 'minikanban_async_job_plugins');
  }

  /**
   * Get the plugin labels.
   *
   * @return array<string, string|\Drupal\Core\StringTranslation\TranslatableMarkup>
   *   Plugin labels, keyed by ID.
   */
  public static function getPluginLabels(): array {
    return array_map(
      fn (array $definition) => $definition['label'],
      \Drupal::service(self::class)->getDefinitions(),
    );
  }

}
