<?php

declare(strict_types=1);

namespace Drupal\minikanban_agent\EventSubscriber;

use Drupal\ai_agents\Event\AgentResponseEvent;
use Drupal\ai_agents\PluginInterfaces\ConfigAiAgentInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Session\AccountProxyInterface;
use Drupal\minikanban\EpicInterface;
use Drupal\minikanban\TaskInterface;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Event subscriber to listen to comments from agents and save them.
 */
final readonly class MinikanbanCommentSubscriber implements EventSubscriberInterface {

  /**
   * Constructs a MinikanbanCommentSubscriber object.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entityTypeManager
   *   The entity type manager.
   * @param \Drupal\Core\Session\AccountProxyInterface $currentUser
   *   The current user.
   */
  public function __construct(
    private EntityTypeManagerInterface $entityTypeManager,
    private AccountProxyInterface $currentUser,
  ) {}

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents(): array {
    return [
      AgentResponseEvent::EVENT_NAME => ['onAgentResponse'],
    ];
  }

  /**
   * Add a comment on an agent response.
   *
   * @param \Drupal\ai_agents\Event\AgentResponseEvent $event
   *   The agent response event.
   */
  public function onAgentResponse(AgentResponseEvent $event): void {
    $agent = $event->getAgent();
    if (!$agent instanceof ConfigAiAgentInterface) {
      return;
    }

    $tokens = $agent->getTokenContexts();
    $entity = $tokens['kanban_task'] ?? $tokens['kanban_epic'];
    if (!$entity) {
      return;
    }
    assert($entity instanceof EpicInterface || $entity instanceof TaskInterface);

    $message = $event->getResponse()->getNormalized()->getText();
    if ($message) {
      $entity->addComment(
        $message,
        $this->currentUser->id(),
      );
    }
  }

}
