<?php

namespace Drupal\minikanban_agent\Hook;

use Drupal\ai_agents\PluginInterfaces\ConfigAiAgentInterface;
use Drupal\ai_agents\PluginManager\AiAgentManager;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Hook\Attribute\Hook;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Symfony\Component\DependencyInjection\Attribute\Autowire;

/**
 * Form alter for the AI agent explorer form.
 */
class AiAgentExplorerFormAlter {

  use StringTranslationTrait;

  public function __construct(
    #[Autowire('@plugin.manager.ai_agents')]
    private readonly AiAgentManager $aiAgentManager,
  ) {}

  /**
   * Expose kanban tokens for the explorer.
   *
   * @param array $form
   *   The form array.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The form state.
   * @param string $form_id
   *   The form ID.
   */
  #[Hook('form_ai_agents_explorer_alter')]
  public function addKanbanTokens(array &$form, FormStateInterface $form_state, string $form_id): void {
    $agent_id = $form_state->getValue('agent') ?? $form['wrapper']['agent']['#default_value'];
    if (!$agent_id) {
      return;
    }

    $agent = $this->aiAgentManager->createInstance($agent_id);
    if (!$agent instanceof ConfigAiAgentInterface) {
      return;
    }

    $form['wrapper']['tokens']['kanban_project'] = [
      '#type' => 'textfield',
      '#title' => new TranslatableMarkup('Project ID'),
    ];
    $form['wrapper']['tokens']['kanban_epic'] = [
      '#type' => 'textfield',
      '#title' => new TranslatableMarkup('Epic ID'),
    ];
    $form['wrapper']['tokens']['kanban_task'] = [
      '#type' => 'textfield',
      '#title' => new TranslatableMarkup('Task ID'),
    ];
  }

}
