<?php

declare(strict_types=1);

namespace Drupal\minikanban_agent\Hook;

use Drupal\Core\Hook\Attribute\Hook;
use Drupal\minikanban\Entity\Epic;
use Drupal\minikanban\Entity\Task;

/**
 * AI Function Call plugin definition hooks.
 */
readonly class AiFunctionCallInfo {

  /**
   * Add constraints for the status context.
   *
   * @param array<string, array{context_definitions: array<string, \Drupal\Core\Plugin\Context\ContextDefinition>}> $definitions
   *   The function call plugin definitions.
   */
  #[Hook('ai_function_call_info_alter')]
  public function setStatusContextConstraints(array &$definitions): void {
    // Epic status.
    $epic_statuses = array_keys(Epic::$epicStatuses);

    $epic_plugins = [
      'minikanban_epic_list' => TRUE,
      'minikanban_epic_create' => FALSE,
      'minikanban_epic_update' => FALSE,
    ];
    foreach ($epic_plugins as $plugin_id => $multiple) {
      if (isset($definitions[$plugin_id])) {
        $context_definition = $definitions[$plugin_id]['context_definitions']['status'];
        $context_definition->addConstraint(
          'Choice',
          [
            'choices' => $epic_statuses,
            'multiple' => $multiple,
          ],
        );
      }
    }

    // Task status.
    $task_statuses = array_keys(Task::$taskStatuses);
    $task_plugins = [
      'minikanban_task_list' => TRUE,
      'minikanban_task_create' => FALSE,
      'minikanban_task_update' => FALSE,
    ];
    foreach ($task_plugins as $plugin_id => $multiple) {
      if (isset($definitions[$plugin_id])) {
        $context_definition = $definitions[$plugin_id]['context_definitions']['status'];
        $context_definition->addConstraint(
          'Choice',
          [
            'choices' => $task_statuses,
            'multiple' => $multiple,
          ],
        );
      }
    }
  }

}
