<?php

declare(strict_types=1);

namespace Drupal\minikanban_agent\Hook;

use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Field\BaseFieldDefinition;
use Drupal\Core\Hook\Attribute\Hook;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\Core\StringTranslation\TranslationInterface;

/**
 * Field info hooks for minikanban agent.
 */
final class KanbanFieldInfo {

  use StringTranslationTrait;

  /**
   * Constructs an EntityFieldInfo object.
   */
  public function __construct(
    TranslationInterface $string_translation,
  ) {
    $this->setStringTranslation($string_translation);
  }

  /**
   * Provides base field info for Kanban entities.
   *
   * @param \Drupal\Core\Entity\EntityTypeInterface $entity_type
   *   The entity type to add fields to.
   *
   * @return array<string, \Drupal\Core\Field\BaseFieldDefinition>
   *   An array of base field definitions.
   */
  #[Hook('entity_base_field_info')]
  public function baseFields(EntityTypeInterface $entity_type): array {
    $fields = [];

    if (in_array($entity_type->id(), ['kanban_project', 'kanban_epic', 'kanban_task'])) {
      $fields['ai_agent'] = BaseFieldDefinition::create('entity_reference')
        ->setSetting('target_type', 'ai_agent')
        ->setDisplayConfigurable('form', TRUE)
        ->setDisplayOptions('form', [
          'type' => 'options_select',
          'weight' => 50,
        ])
        ->setDisplayConfigurable('view', TRUE);

      if ($entity_type->id() == 'kanban_task') {
        $fields['ai_agent']
          ->setLabel($this->t('AI agent'))
          ->setDescription($this->t('The AI agent responsible for executing the task.'));
      }
      else {
        $fields['ai_agent']
          ->setRequired(TRUE)
          ->setDefaultValue('minikanban_generic')
          ->setLabel($this->t('AI orchestration agent'))
          ->setDescription($this->t('The AI agent responsible for task orchestration.'));
      }
    }

    return $fields;
  }

}
