<?php

namespace Drupal\minikanban_agent\Hook;

use Drupal\ai_agents\AiAgentInterface as AiAgentEntityInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Hook\Attribute\Hook;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\minikanban_agent\AgentHelper;
use Symfony\Component\HttpFoundation\RequestStack;

/**
 * Form alter for the kanban project entity form.
 */
class ProjectFormAlter {

  use StringTranslationTrait;

  public function __construct(
    private readonly RequestStack $requestStack,
    private readonly AgentHelper $minikanbanAgentHelper,
  ) {}

  /**
   * Alter the orchestration agent options.
   *
   * @param array $form
   *   The form array.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The form state.
   * @param string $form_id
   *   The form ID.
   */
  #[Hook('form_kanban_project_form_alter')]
  public function alterOrchestrationAgents(array &$form, FormStateInterface $form_state, string $form_id): void {
    // @todo Move this to a selection handler so it applies to all widgets.
    if (isset($form['ai_agent']['widget']) && $form['ai_agent']['widget']['#type'] === 'select') {
      $form['ai_agent']['widget']['#empty_option'] = $this->t('-- Let Minikanban decide --');
      $form['ai_agent']['widget']['#options'] = array_intersect_key(
        $form['ai_agent']['widget']['#options'],
        array_filter(
          \Drupal::entityTypeManager()
            ->getStorage('ai_agent')
            ->loadMultiple(array_keys($form['ai_agent']['widget']['#options'])),
          fn (AiAgentEntityInterface $agent) => $agent->get('orchestration_agent'),
        ),
      );

      // If this is the add form and we have a query param setting the swarm,
      // auto select it.
      if ($form_id === 'kanban_project_add_form') {
        $swarm = $this->requestStack->getCurrentRequest()->query->get('swarm');
        if ($swarm) {
          $form['ai_agent']['widget']['#default_value'] = $swarm;

          // Also include the AI user as a member.
          if (isset($form['members']['widget']['target_id'])) {
            $form['members']['widget']['target_id']['#default_value'][] = $this->minikanbanAgentHelper->getAiAgent();
          }
        }
      }
    }
  }

}
