<?php

namespace Drupal\minikanban_agent\Hook;

use Drupal\Core\Hook\Attribute\Hook;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\Core\StringTranslation\TranslationInterface;
use Drupal\minikanban_agent\AsyncJobManager;
use Drupal\minikanban_agent\AsyncJobPluginManager;
use Drupal\minikanban_agent\Enum\AsyncJobStatus;

/**
 * Views data hooks for minikanban agents.
 */
class ViewsData {

  use StringTranslationTrait;

  public function __construct(
    TranslationInterface $string_translation,
  ) {
    $this->stringTranslation = $string_translation;
  }

  /**
   * Implements hook_views_data().
   *
   * @return array<string, array<string, mixed>>
   *   The views data.
   */
  #[Hook('views_data')]
  public function data(): array {
    $data = [];

    $data[AsyncJobManager::TABLE] = [
      'table' => [
        'group' => $this->t('Minikanban'),
        'base' => [
          'field' => 'uuid',
          'title' => $this->t('Asynchronous jobs'),
          'help' => $this->t('Asynchronous jobs for tasks managed by the minikanban agents.'),
        ],
      ],
    ];

    $data[AsyncJobManager::TABLE]['uuid'] = [
      'title' => $this->t('UUID'),
      'field' => ['id' => 'standard'],
    ];

    $data[AsyncJobManager::TABLE]['task'] = [
      'title' => $this->t('Task ID'),
      'field' => ['id' => 'standard'],
      'filter' => ['id' => 'standard'],
      'argument' => ['id' => 'standard'],
      'sort' => ['id' => 'numeric'],
      'relationship' => [
        'base' => 'kanban_task',
        'base field' => 'id',
        'id' => 'standard',
        'label' => $this->t('Task'),
      ],
    ];

    $data[AsyncJobManager::TABLE]['plugin'] = [
      'title' => $this->t('Plugin'),
      'field' => [
        'id' => 'machine_name',
        'options callback' => [AsyncJobPluginManager::class, 'getPluginLabels'],
      ],
      'filter' => ['id' => 'standard'],
    ];

    $data[AsyncJobManager::TABLE]['label'] = [
      'title' => $this->t('Label'),
      'field' => ['id' => 'standard'],
    ];

    $data[AsyncJobManager::TABLE]['status'] = [
      'title' => $this->t('Status'),
      'field' => [
        'id' => 'machine_name',
        'options callback' => [AsyncJobStatus::class, 'getOptions'],
      ],
      'filter' => [
        'id' => 'in_operator',
        'options callback' => [AsyncJobStatus::class, 'getOptions'],
      ],
    ];

    $data[AsyncJobManager::TABLE]['created'] = [
      'title' => $this->t('Created'),
      'field' => ['id' => 'date'],
      'filter' => ['id' => 'date'],
      'sort' => ['id' => 'date'],
    ];

    $data[AsyncJobManager::TABLE]['completed'] = [
      'title' => $this->t('Completed'),
      'field' => ['id' => 'date'],
      'filter' => ['id' => 'date'],
      'sort' => ['id' => 'date'],
    ];

    $data[AsyncJobManager::TABLE]['progress'] = [
      'title' => $this->t('Progress'),
      'field' => ['id' => 'date'],
      'filter' => ['id' => 'date'],
      'sort' => ['id' => 'date'],
    ];

    $data[AsyncJobManager::TABLE]['description'] = [
      'title' => $this->t('Status description'),
      'field' => ['id' => 'standard'],
    ];

    return $data;
  }

}
